fun_changed: Check if a core R function changed between R versions
Description
Check if a core R function changed between R versions
Usage
fun_changed(fn, from = NULL, to = NULL, package = NULL)
Arguments
fn
Character name of a function in a core R package.
from
Minimum R version (optional).
to
Maximum R version (optional).
package
Name of the package (optional).
Value
0 if there was no change. 1 if the function's arguments changed.
2 if the function was not present in all versions. If the function can't
be found or exists in multiple packages, throws an error.