rcheology is a data package providing two data frames:
Functions not built on the relevant platform - e.g. Windows functions - are not included.
Because data is collected using the original R version, it is subject to changes in the way
R works. For example, before 2.5.0, args() didn't work on Primitive functions, so
those functions have no value in the args column.
I have failed to build tcltk on R versions 1.0.1-1.4.1 and 1.7.0/1, so there's no tcltk data for these versions. If you can help, get in touch.
rcheology lists objects in all versions of R from 1.0.1 onwards.
Rversions lists R versions and their release dates. NB: For a more complete and "canonical" solution, see the rversions package.
The version of the rcheology package reflects the latest R version to be included in the data, e.g. 3.5.1.x contains data up to and including R 3.5.1.
An online app for data exploration is available at https://hughjonesd.shinyapps.io/rcheology/.
Versions 4.0.0 and up are installed from the CRAN apt repositories for Ubuntu Bionic.
Versions 3.0.1 to 3.6.3 are installed from the CRAN apt repositories for Ubuntu Trusty Tahr. Version 3.5.0 and up use a special repository.
Versions 2.5.1 to 3.0.0 are built from source on Ubuntu Lucid Lynx.
Versions 1.2.3 to 2.4.1 are mostly built from source on Debian Sarge.
Versions 1.0.1 to 1.2.2 (and a couple of later versions) are built from source on Debian Woody.
Results are found from running ls on all installed packages from a
minimal installation. Recommended packages are not included.
The Rversions data frame lists versions of R and release dates.